module TestFixture(CLK,Reset,PC, Instr, ALUResult, rtdata, bubble, DataIn);
	parameter PRGM = "regression.hex";
	parameter PRGM_SIZE = 124;	 
	parameter VERIFIER = "verify.ver";
	parameter VERF_SIZE = 124;
	parameter IGNORE = 32'hDEADBEEF;
	parameter MESSAGE = "messages.msg";
	parameter MSG_SIZE = 1024;
	input bubble,CLK,Reset;
	input [31:0] PC, ALUResult, rtdata, DataIn;
	output wire [31:0] Instr;
	reg [31:0] prgm [0:PRGM_SIZE], vALU[0:PRGM_SIZE], vPC[0:PRGM_SIZE], vRT[0:PRGM_SIZE], vDIN[0:PRGM_SIZE];
	reg [127:0] verf [0:VERF_SIZE];
	integer cmds_read, i;
	wire [31:0] verify_ALU,verify_RT,verify_DataIn,new_verify_PC,old_verify_PC; 
	reg [7:0] index = 8'h00;
	initial begin
			cmds_read = 0;
			
			// clear out program memory
			for (i = 0; i < PRGM_SIZE; i = i + 1) begin
					prgm[i] = 32'hFFFFFFFF;
					verf[i] = 128'hFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF;
				end
			
			// load program from PRGM
			$readmemh(PRGM, prgm,0,PRGM_SIZE);
			$readmemh(VERIFIER, verf,0,PRGM_SIZE); 
			for (i = 0; i < PRGM_SIZE; i = i + 1) begin
					vRT[i] = verf[i][127:96];
					vALU[i] = verf[i][95:64];
					vPC[i] = verf[i][63:32];
					vDIN[i] = verf[i][31:0];
					$display("%h %h\n",prgm[i],verf[i]);
				end
			
		end
	assign Instr = (Reset)? 0 : prgm[(PC>>2)];
	
	assign verify_ALU =(Reset)? 0 : vALU[index];
	assign verify_RT = (Reset)? 0 : vRT[index];
	assign new_verify_PC = (Reset)? 0: vPC[index];
	assign verify_DataIn = (Reset)? 0 :vDIN[index];	 
	
	wire alu_match = (verify_ALU == IGNORE)|(verify_ALU == ALUResult);	
	wire pc_match = (new_verify_PC == IGNORE)|(new_verify_PC == PC);
	wire rt_match = (verify_RT == IGNORE)|(verify_RT == rtdata);
	wire din_match = (verify_DataIn == IGNORE)|(verify_DataIn == DataIn);
	wire done = ({verify_ALU,verify_RT,new_verify_PC,verify_DataIn} == {IGNORE,IGNORE,IGNORE,IGNORE});
	

	always @(posedge CLK) begin
			index <= (Reset)? 8'h00 : (index + 8'h01);
			if(done) begin
					$display("Completed Successfully!\n");
					$stop;
				end
			
			$strobe(" [%h] %h, %h, %h\n <%h>, %h, %h, %h",PC,ALUResult,rtdata,DataIn,new_verify_PC,verify_ALU,verify_RT,verify_DataIn);
			
			if((Reset == 1'b0)) begin
					
					if(~alu_match) begin
							$display("ALU Result does not match verification file! %h != %h",ALUResult, verify_ALU);									
						end
					if(~rt_match) begin
							$display("RT does not match verification file! %h != %h",rtdata,verify_RT);
						end
					if(~din_match) begin
							$display("DataIn does not match verification file! %h != %h",DataIn,verify_DataIn);
						end
					if(~pc_match) begin
							$display("PC does not match verification file! %h != %h",PC,new_verify_PC);
						end
					if((pc_match & din_match & rt_match & alu_match) == 1'b0) begin
							$stop;
						end
				end
		end	 
	
endmodule